@@ -7,7 +7,7 @@ use Cwd;
 use IO::File;
 use File::Spec::Functions qw(splitdir catfile);
 
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 our $modeline;
 
 require Exporter;
@@ -93,12 +93,12 @@ __DATA__
 #--%X--%X followme.cfg
 run_before = App::Followme::FormatPage
 run_before = App::Followme::ConvertPage
+
 #--%X--%X archive/followme.cfg
 run_before = App::Followme::CreateNews
 news_index_file = index.html
 news_file = ../blog.html
 #--%X--%X templates/page.htm
-<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
 <html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
@@ -110,12 +110,6 @@ news_file = ../blog.html
 <div id="header">
 <h1>Site Title</h1>
 </div>
-<div id="sidebar">
-<!-- section navigation -->
-<!-- endsection navigation -->
-<!-- section sidebar -->
-<!-- endsection sidebar -->
-</div>
 <div id="content">
 <!-- section content -->
 <h2>$title</h2>
@@ -126,7 +120,6 @@ $body
 </html>
 
 #--%X--%X templates/news.htm
-<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
 <html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
@@ -138,12 +131,6 @@ $body
 <div id="header">
 <h1>Site Title</h1>
 </div>
-<div id="sidebar">
-<!-- section navigation -->
-<!-- endsection navigation -->
-<!-- section sidebar -->
-<!-- endsection sidebar -->
-</div>
 <div id="content">
 <!-- section content -->
 <!-- for @loop -->
@@ -168,12 +155,6 @@ $body
 <div id="header">
 <h1>Site Title</h1>
 </div>
-<div id="sidebar">
-<!-- section navigation -->
-<!-- endsection navigation -->
-<!-- section sidebar -->
-<!-- endsection sidebar -->
-</div>
 <div id="content">
 <!-- section content -->
 <h2>$title</h2>
@@ -200,12 +181,6 @@ $body
 <div id="header">
 <h1>Site Title</h1>
 </div>
-<div id="sidebar">
-<!-- section navigation -->
-<!-- endsection navigation -->
-<!-- section sidebar -->
-<!-- endsection sidebar -->
-</div>
 <div id="content">
 <!-- section content -->
 <h2>$title</h2>
@@ -219,4 +194,3 @@ $body
 </div>
 </body>
 </html>
-
